@@ -95,7 +95,7 @@ class Exceptions:
 
 class IoTAnalyticsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html)
     """
 
@@ -113,7 +113,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Sends messages to a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.batch_put_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.batch_put_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#batch_put_message)
         """
 
@@ -121,7 +121,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#can_paginate)
         """
 
@@ -131,7 +131,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Cancels the reprocessing of data through the pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.cancel_pipeline_reprocessing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.cancel_pipeline_reprocessing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#cancel_pipeline_reprocessing)
         """
 
@@ -139,14 +139,14 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         channelName: str,
-        channelStorage: "ChannelStorageTypeDef" = None,
-        retentionPeriod: "RetentionPeriodTypeDef" = None,
-        tags: Sequence["TagTypeDef"] = None
+        channelStorage: "ChannelStorageTypeDef" = ...,
+        retentionPeriod: "RetentionPeriodTypeDef" = ...,
+        tags: Sequence["TagTypeDef"] = ...
     ) -> CreateChannelResponseTypeDef:
         """
         Used to create a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.create_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.create_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#create_channel)
         """
 
@@ -155,28 +155,28 @@ class IoTAnalyticsClient(BaseClient):
         *,
         datasetName: str,
         actions: Sequence["DatasetActionTypeDef"],
-        triggers: Sequence["DatasetTriggerTypeDef"] = None,
-        contentDeliveryRules: Sequence["DatasetContentDeliveryRuleTypeDef"] = None,
-        retentionPeriod: "RetentionPeriodTypeDef" = None,
-        versioningConfiguration: "VersioningConfigurationTypeDef" = None,
-        tags: Sequence["TagTypeDef"] = None,
-        lateDataRules: Sequence["LateDataRuleTypeDef"] = None
+        triggers: Sequence["DatasetTriggerTypeDef"] = ...,
+        contentDeliveryRules: Sequence["DatasetContentDeliveryRuleTypeDef"] = ...,
+        retentionPeriod: "RetentionPeriodTypeDef" = ...,
+        versioningConfiguration: "VersioningConfigurationTypeDef" = ...,
+        tags: Sequence["TagTypeDef"] = ...,
+        lateDataRules: Sequence["LateDataRuleTypeDef"] = ...
     ) -> CreateDatasetResponseTypeDef:
         """
         Used to create a dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#create_dataset)
         """
 
     def create_dataset_content(
-        self, *, datasetName: str, versionId: str = None
+        self, *, datasetName: str, versionId: str = ...
     ) -> CreateDatasetContentResponseTypeDef:
         """
         Creates the content of a dataset by applying a `queryAction` (a SQL query) or a
         `containerAction` (executing a containerized application).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset_content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.create_dataset_content)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#create_dataset_content)
         """
 
@@ -184,16 +184,16 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         datastoreName: str,
-        datastoreStorage: "DatastoreStorageTypeDef" = None,
-        retentionPeriod: "RetentionPeriodTypeDef" = None,
-        tags: Sequence["TagTypeDef"] = None,
-        fileFormatConfiguration: "FileFormatConfigurationTypeDef" = None,
-        datastorePartitions: "DatastorePartitionsTypeDef" = None
+        datastoreStorage: "DatastoreStorageTypeDef" = ...,
+        retentionPeriod: "RetentionPeriodTypeDef" = ...,
+        tags: Sequence["TagTypeDef"] = ...,
+        fileFormatConfiguration: "FileFormatConfigurationTypeDef" = ...,
+        datastorePartitions: "DatastorePartitionsTypeDef" = ...
     ) -> CreateDatastoreResponseTypeDef:
         """
         Creates a data store, which is a repository for messages.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.create_datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.create_datastore)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#create_datastore)
         """
 
@@ -202,12 +202,12 @@ class IoTAnalyticsClient(BaseClient):
         *,
         pipelineName: str,
         pipelineActivities: Sequence["PipelineActivityTypeDef"],
-        tags: Sequence["TagTypeDef"] = None
+        tags: Sequence["TagTypeDef"] = ...
     ) -> CreatePipelineResponseTypeDef:
         """
         Creates a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#create_pipeline)
         """
 
@@ -215,7 +215,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Deletes the specified channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#delete_channel)
         """
 
@@ -223,15 +223,15 @@ class IoTAnalyticsClient(BaseClient):
         """
         Deletes the specified dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#delete_dataset)
         """
 
-    def delete_dataset_content(self, *, datasetName: str, versionId: str = None) -> None:
+    def delete_dataset_content(self, *, datasetName: str, versionId: str = ...) -> None:
         """
         Deletes the content of the specified dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset_content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_dataset_content)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#delete_dataset_content)
         """
 
@@ -239,7 +239,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Deletes the specified data store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_datastore)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#delete_datastore)
         """
 
@@ -247,17 +247,17 @@ class IoTAnalyticsClient(BaseClient):
         """
         Deletes the specified pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#delete_pipeline)
         """
 
     def describe_channel(
-        self, *, channelName: str, includeStatistics: bool = None
+        self, *, channelName: str, includeStatistics: bool = ...
     ) -> DescribeChannelResponseTypeDef:
         """
         Retrieves information about a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#describe_channel)
         """
 
@@ -265,17 +265,17 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves information about a dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#describe_dataset)
         """
 
     def describe_datastore(
-        self, *, datastoreName: str, includeStatistics: bool = None
+        self, *, datastoreName: str, includeStatistics: bool = ...
     ) -> DescribeDatastoreResponseTypeDef:
         """
         Retrieves information about a data store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_datastore)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#describe_datastore)
         """
 
@@ -283,7 +283,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves the current settings of the IoT Analytics logging options.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_logging_options)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_logging_options)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#describe_logging_options)
         """
 
@@ -291,41 +291,41 @@ class IoTAnalyticsClient(BaseClient):
         """
         Retrieves information about a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.describe_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#describe_pipeline)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#generate_presigned_url)
         """
 
     def get_dataset_content(
-        self, *, datasetName: str, versionId: str = None
+        self, *, datasetName: str, versionId: str = ...
     ) -> GetDatasetContentResponseTypeDef:
         """
         Retrieves the contents of a dataset as presigned URIs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.get_dataset_content)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.get_dataset_content)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#get_dataset_content)
         """
 
     def list_channels(
-        self, *, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = ..., maxResults: int = ...
     ) -> ListChannelsResponseTypeDef:
         """
         Retrieves a list of channels.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.list_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.list_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_channels)
         """
 
@@ -333,45 +333,45 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         datasetName: str,
-        nextToken: str = None,
-        maxResults: int = None,
-        scheduledOnOrAfter: Union[datetime, str] = None,
-        scheduledBefore: Union[datetime, str] = None
+        nextToken: str = ...,
+        maxResults: int = ...,
+        scheduledOnOrAfter: Union[datetime, str] = ...,
+        scheduledBefore: Union[datetime, str] = ...
     ) -> ListDatasetContentsResponseTypeDef:
         """
         Lists information about dataset contents that have been created.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.list_dataset_contents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.list_dataset_contents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_dataset_contents)
         """
 
     def list_datasets(
-        self, *, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = ..., maxResults: int = ...
     ) -> ListDatasetsResponseTypeDef:
         """
         Retrieves information about datasets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_datasets)
         """
 
     def list_datastores(
-        self, *, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = ..., maxResults: int = ...
     ) -> ListDatastoresResponseTypeDef:
         """
         Retrieves a list of data stores.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datastores)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.list_datastores)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_datastores)
         """
 
     def list_pipelines(
-        self, *, nextToken: str = None, maxResults: int = None
+        self, *, nextToken: str = ..., maxResults: int = ...
     ) -> ListPipelinesResponseTypeDef:
         """
         Retrieves a list of pipelines.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_pipelines)
         """
 
@@ -379,7 +379,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Lists the tags (metadata) that you have assigned to the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#list_tags_for_resource)
         """
 
@@ -387,7 +387,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Sets or updates the IoT Analytics logging options.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.put_logging_options)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.put_logging_options)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#put_logging_options)
         """
 
@@ -400,7 +400,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Simulates the results of running a pipeline activity on a message payload.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.run_pipeline_activity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.run_pipeline_activity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#run_pipeline_activity)
         """
 
@@ -408,15 +408,15 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         channelName: str,
-        maxMessages: int = None,
-        startTime: Union[datetime, str] = None,
-        endTime: Union[datetime, str] = None
+        maxMessages: int = ...,
+        startTime: Union[datetime, str] = ...,
+        endTime: Union[datetime, str] = ...
     ) -> SampleChannelDataResponseTypeDef:
         """
         Retrieves a sample of messages from the specified channel ingested during the
         specified timeframe.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.sample_channel_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.sample_channel_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#sample_channel_data)
         """
 
@@ -424,14 +424,14 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         pipelineName: str,
-        startTime: Union[datetime, str] = None,
-        endTime: Union[datetime, str] = None,
-        channelMessages: "ChannelMessagesTypeDef" = None
+        startTime: Union[datetime, str] = ...,
+        endTime: Union[datetime, str] = ...,
+        channelMessages: "ChannelMessagesTypeDef" = ...
     ) -> StartPipelineReprocessingResponseTypeDef:
         """
         Starts the reprocessing of raw message data through the pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.start_pipeline_reprocessing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.start_pipeline_reprocessing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#start_pipeline_reprocessing)
         """
 
@@ -439,7 +439,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Adds to or modifies the tags of the given resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#tag_resource)
         """
 
@@ -447,7 +447,7 @@ class IoTAnalyticsClient(BaseClient):
         """
         Removes the given tags (metadata) from the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#untag_resource)
         """
 
@@ -455,13 +455,13 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         channelName: str,
-        channelStorage: "ChannelStorageTypeDef" = None,
-        retentionPeriod: "RetentionPeriodTypeDef" = None
+        channelStorage: "ChannelStorageTypeDef" = ...,
+        retentionPeriod: "RetentionPeriodTypeDef" = ...
     ) -> None:
         """
         Used to update the settings of a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.update_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.update_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#update_channel)
         """
 
@@ -470,16 +470,16 @@ class IoTAnalyticsClient(BaseClient):
         *,
         datasetName: str,
         actions: Sequence["DatasetActionTypeDef"],
-        triggers: Sequence["DatasetTriggerTypeDef"] = None,
-        contentDeliveryRules: Sequence["DatasetContentDeliveryRuleTypeDef"] = None,
-        retentionPeriod: "RetentionPeriodTypeDef" = None,
-        versioningConfiguration: "VersioningConfigurationTypeDef" = None,
-        lateDataRules: Sequence["LateDataRuleTypeDef"] = None
+        triggers: Sequence["DatasetTriggerTypeDef"] = ...,
+        contentDeliveryRules: Sequence["DatasetContentDeliveryRuleTypeDef"] = ...,
+        retentionPeriod: "RetentionPeriodTypeDef" = ...,
+        versioningConfiguration: "VersioningConfigurationTypeDef" = ...,
+        lateDataRules: Sequence["LateDataRuleTypeDef"] = ...
     ) -> None:
         """
         Updates the settings of a dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.update_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.update_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#update_dataset)
         """
 
@@ -487,14 +487,14 @@ class IoTAnalyticsClient(BaseClient):
         self,
         *,
         datastoreName: str,
-        retentionPeriod: "RetentionPeriodTypeDef" = None,
-        datastoreStorage: "DatastoreStorageTypeDef" = None,
-        fileFormatConfiguration: "FileFormatConfigurationTypeDef" = None
+        retentionPeriod: "RetentionPeriodTypeDef" = ...,
+        datastoreStorage: "DatastoreStorageTypeDef" = ...,
+        fileFormatConfiguration: "FileFormatConfigurationTypeDef" = ...
     ) -> None:
         """
         Used to update the settings of a data store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.update_datastore)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.update_datastore)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#update_datastore)
         """
 
@@ -504,14 +504,14 @@ class IoTAnalyticsClient(BaseClient):
         """
         Updates the settings of a pipeline.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Client.update_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Client.update_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/client.html#update_pipeline)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_channels"]) -> ListChannelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListChannels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators.html#listchannelspaginator)
         """
 
@@ -520,27 +520,27 @@ class IoTAnalyticsClient(BaseClient):
         self, operation_name: Literal["list_dataset_contents"]
     ) -> ListDatasetContentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasetContents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators.html#listdatasetcontentspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datasets"]) -> ListDatasetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators.html#listdatasetspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_datastores"]) -> ListDatastoresPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListDatastores)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators.html#listdatastorespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.54/reference/services/iotanalytics.html#IoTAnalytics.Paginator.ListPipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iotanalytics/paginators.html#listpipelinespaginator)
         """
